@@ -17,8 +17,9 @@ class WaitWindow(QWidget):
         super().__init__(parent)
         self.setWindowFlag(Qt.Window)
         self.setWindowFlag(Qt.FramelessWindowHint)
+        self.setMinimumWidth(500)
 
-        self.setWindowModality(Qt.ApplicationModal)
+        # self.setWindowModality(Qt.ApplicationModal)
 
         self.spinner = Spinner(self)
         self.update_button = QPushButton('Update')
@@ -54,8 +55,6 @@ class WaitWindow(QWidget):
 
     @pyqtSlot(object, name='checkOutdated')
     def get_result(self, res: CheckVersionMessage):
-        self.log.error('received result')
-
         if res == CheckVersionMessage.no_internet:
             self.set_text('Could not check the latest version (connection error).')
         if res == CheckVersionMessage.error:
